#
# spec file for package gnome-desktop
#
# Copyright (c) 2021 SUSE LLC
#
# All modifications and additions to the file contributed by third parties
# remain the property of their copyright owners, unless otherwise agreed
# upon. The license for this file, and modifications and additions to the
# file, is the same license as for the pristine package itself (unless the
# license for the pristine package is not an Open Source License, in which
# case the license is the MIT License). An "Open Source License" is a
# license that conforms to the Open Source Definition (Version 1.9)
# published by the Open Source Initiative.

# Please submit bugfixes or comments via https://bugs.opensuse.org/
#


Name:           gnome-desktop
Version:        41.2
Release:        150400.1.7
Summary:        The GNOME Desktop API Library
License:        LGPL-2.1-or-later
Group:          System/GUI/GNOME
URL:            https://www.gnome.org
Source0:        https://download.gnome.org/sources/gnome-desktop/41/%{name}-%{version}.tar.xz

# PATCH-FIX-OPENSUSE gnome-desktop-switch-Japanese-default-input-to-mozc.patch bnc#1029083 boo#1056289 qzhao@suse.com -- Switch new user's default input engine from "anthy" to "mozc" in gnome-desktop with Japanese language and ibus input frame-work condition.
Patch1:         gnome-desktop-switch-Japanese-default-input-to-mozc.patch

BuildRequires:  fdupes
BuildRequires:  gobject-introspection-devel
BuildRequires:  gtk-doc
BuildRequires:  intltool
BuildRequires:  libxkbregistry0
BuildRequires:  meson >= 0.49.0
BuildRequires:  pkgconfig
BuildRequires:  yelp-tools
BuildRequires:  pkgconfig(gdk-pixbuf-2.0) >= 2.36.5
BuildRequires:  pkgconfig(gio-unix-2.0)
BuildRequires:  pkgconfig(glib-2.0) >= 2.53.0
BuildRequires:  pkgconfig(gsettings-desktop-schemas) >= 3.31.0
BuildRequires:  pkgconfig(gtk+-3.0) >= 3.3.6
BuildRequires:  pkgconfig(iso-codes)
BuildRequires:  pkgconfig(libseccomp)
BuildRequires:  pkgconfig(libsystemd)
BuildRequires:  pkgconfig(libudev)
BuildRequires:  pkgconfig(xkbfile)
BuildRequires:  pkgconfig(xkbregistry)
BuildRequires:  pkgconfig(xkeyboard-config)

%description
This package contains the desktop-wide files.

%package -n gnome-version
Summary:        GNOME version
Group:          System/GUI/GNOME

%description -n gnome-version
This package contains information on the version of GNOME that is installed.

%package -n libgnome-desktop-3_0-common
Summary:        Common data files for the GNOME Desktop API library
Group:          System/Libraries

%description -n libgnome-desktop-3_0-common
The libgnome-desktop library provides API shared by several applications
on the desktop, but that cannot live in the platform for various
reasons.

This package contains data files used by libgnome-dekstop.

%package -n libgnome-desktop-3-19
Summary:        The GNOME Desktop API Library
# the library calls out to bwrap in order to fire up thumbnailers in a secure container
Group:          System/Libraries
Requires:       bubblewrap
Requires:       gsettings-desktop-schemas
# Data files for libgnome-desktop, split in an own package for SLPP compliancy
Requires:       libgnome-desktop-3_0-common >= %{version}
Provides:       %{name} = %{version}
Obsoletes:      %{name} < %{version}

%description -n libgnome-desktop-3-19
The libgnome-desktop library provides API shared by several applications
on the desktop, but that cannot live in the platform for various
reasons.

%package -n typelib-1_0-GnomeDesktop-3_0
Summary:        Introspection bindings for the GNOME Desktop API library
Group:          System/Libraries

%description -n typelib-1_0-GnomeDesktop-3_0
The libgnome-desktop library provides API shared by several applications
on the desktop, but that cannot live in the platform for various
reasons.

This package provides the GObject Introspection bindings for
libgnome-desktop.

%package -n libgnome-desktop-3-devel
Summary:        Development files for the GNOME Desktop API library
Group:          Development/Libraries/GNOME
Requires:       libgnome-desktop-3-19 = %{version}
# Needed as /usr/include/gnome-desktop-3.0/libgnome-desktop/gnome-xkb-info.h includes X11/extensions/XKBrules.h
Requires:       libxkbfile-devel
Requires:       typelib-1_0-GnomeDesktop-3_0 = %{version}
Provides:       %{name}-devel = %{version}
Obsoletes:      %{name}-devel < %{version}
Provides:       %{name}-doc = %{version}
Obsoletes:      %{name}-doc < %{version}

%description -n libgnome-desktop-3-devel
The libgnome-desktop library provides API shared by several applications
on the desktop, but that cannot live in the platform for various
reasons.

%lang_package

%prep
%autosetup -p1

%build
%meson \
	-Dgnome_distributor=openSUSE \
	-Ddate_in_gnome_version=false \
	-Ddesktop_docs=true \
	-Dgtk_doc=true \
	%{nil}
%meson_build

%install
%meson_install

%find_lang %{name}-3.0 %{?no_lang_C}
%find_lang fdl %{?no_lang_C} %{name}-3.0.lang
%find_lang gpl %{?no_lang_C} %{name}-3.0.lang
%find_lang lgpl %{?no_lang_C} %{name}-3.0.lang

%fdupes %{buildroot}/%{_prefix}

%post -n libgnome-desktop-3-19 -p /sbin/ldconfig
%postun -n libgnome-desktop-3-19 -p /sbin/ldconfig

%files -n libgnome-desktop-3-19
%license COPYING.LIB
%doc AUTHORS NEWS
%{_libdir}/libgnome-desktop-3.so.*

%files -n libgnome-desktop-3_0-common
%doc %{_datadir}/help/C/fdl/
%doc %{_datadir}/help/C/gpl/
%doc %{_datadir}/help/C/lgpl/
%{_libexecdir}/gnome-desktop-debug/
%{_datadir}/locale/en/

%files -n typelib-1_0-GnomeDesktop-3_0
%{_libdir}/girepository-1.0/GnomeDesktop-3.0.typelib

%files -n libgnome-desktop-3-devel
%{_includedir}/gnome-desktop-3.0/
%{_libdir}/libgnome-desktop-3.so
%{_libdir}/pkgconfig/gnome-desktop-3.0.pc
%{_datadir}/gir-1.0/*.gir
%doc %{_datadir}/gtk-doc/html/gnome-desktop3/

%files lang -f %{name}-3.0.lang
# english locale should be in the main package
%exclude %{_datadir}/locale/en

%files -n gnome-version
%dir %{_datadir}/gnome
%{_datadir}/gnome/gnome-version.xml

%changelog
* Tue Dec  7 2021 bjorn.lie@gmail.com
- Update to version 41.2:
  + No changes, version bump only.
* Tue Nov  2 2021 bjorn.lie@gmail.com
- Update to version 41.1:
  + gnome-languages: Avoid passing NULL to newlocale.
  + Avoid the use of `allow-none` for out parameters.
  + Updated translations.
* Mon Sep 20 2021 bjorn.lie@gmail.com
- Update to version 41.0:
  + Updated translations.
* Thu Sep 16 2021 sbrabec@suse.com
- Remove obsolete translation-update-upstream support
  (jsc#SLE-21105).
* Sat Sep  4 2021 bjorn.lie@gmail.com
- Update to version 41.rc:
  + Updated translations.
* Tue Aug 24 2021 dimstar@opensuse.org
- Update to version 41.beta:
  + xkb: Clear cached layouts when necessary.
  + Updated translations.
* Mon Aug 23 2021 dimstar@opensuse.org
- Update to version 41.alpha:
  + Stop mounting ld.so.cache on non-glibc systems.
  + Replace usage of non-portable `uselocale` with locale-dependent
    functions.
  + Fix starttime hour parsing in animated background.
  + xkbinfo: only insert new layouts, skip over duplicate ones.
  + Updated translations.
* Thu Aug 19 2021 bjorn.lie@gmail.com
- Update to version 40.4:
  + No changes.
* Thu Jul 15 2021 bjorn.lie@gmail.com
- Update to version 40.3:
  + Updated translations.
* Thu Jun 10 2021 bjorn.lie@gmail.com
- Update to version 40.2:
  + Fix crash loading keyboard settings panel.
* Mon May  3 2021 dimstar@opensuse.org
- Update to version 40.1:
  + xkbinfo: skip over duplicate layouts.
  + Updated translations.
* Sun Mar 28 2021 dimstar@opensuse.org
- Drop baselibs.conf: no longer build -32bit package. There is no
  consumer left.
* Tue Mar 23 2021 dimstar@opensuse.org
- Update to version 40.0:
  + No changes.
* Fri Mar 19 2021 dimstar@opensuse.org
- Update to version 40.rc:
  + bg-slide-show: Always parse date/time integers in base 10.
  + Thumbnail:
  - Fix thumbnailing of CBZ with UTF-8 filenames.
  - Fix non-working thumbnailer in Flatpak.
  + Updated translations.
* Mon Feb 22 2021 dimstar@opensuse.org
- Update to version 40.beta:
  + xkbinfo: Update iso639Ids but not iso3166Ids correctly in
    evdev.
  + Updated translations.
* Tue Feb 16 2021 dimstar@opensuse.org
- Update to version 40.alpha.0:
  + Add support for x-large and xx-large thumbnail sizes.
  + Make it easier to profile thumbnailers.
  + thumbnailer: Cache GStreamer's plugin registry.
  + Sandbox thumbnailers in Flatpaks.
  + Change default input source to anthy for Japanese>
  + xkbinfo: use libxkbregistry to parse the rules files.
  + Updated translations.
- Add pkgconfig(xkbregistry) BuildRequires: new dependency.
- Rebase gnome-desktop-switch-Japanese-default-input-to-mozc.patch.
* Tue Feb 16 2021 bjorn.lie@gmail.com
- Update to version 3.38.4:
  + Updated translations.
* Fri Jan  8 2021 bjorn.lie@gmail.com
- Update to version 3.38.3:
  + Updated translations.
* Tue Nov 24 2020 bjorn.lie@gmail.com
- Update to version 3.38.2:
  + Updated translations.
* Thu Oct  8 2020 dimstar@opensuse.org
- Update to version 3.38.1:
  + Use GLib fixed-width types.
  + gnome_bg_slide_show_get_current_slide: add NULL check.
  + Updated translations.
- Drop gnome-desktop-invalid-size-crash.patch: fixed upstream.
* Thu Oct  8 2020 dimstar@opensuse.org
- Update to version 3.38.0:
  + Updated translations.
* Thu Oct  8 2020 dimstar@opensuse.org
- Update to version 3.37.92:
  + Updated translations.
* Thu Oct  8 2020 dimstar@opensuse.org
- Update to version 3.37.91:
  + Allow /etc/alternatives in bubblewrap sandbox.
  + Fix bubblewrap sandbox on s390x.
- Changes from version 3.37.90:
  + systemd: Default to garbage collect failed scopes.
  + systemd: Change naming scheme to conform to systemd convention.
- Changes from version 3.37.3:
  + Don't run locale tests at build time.
- Changes from version 3.37.2:
  + languages: Fix encoding issue when translating locale
    modifiers.
  + thumbnails: keep the orignal file name.
- Changes from version 3.37.1:
  + rr: add color transform functions.
  + remove unused direct x11 dependency.
  + Updated translations.
- Drop pkgconfig(x11) BuildRequires: no longer needed.
* Wed Oct  7 2020 bjorn.lie@gmail.com
- Update to version 3.36.7:
  + No changes, version bump only.
* Wed Sep 16 2020 mgorse@suse.com
- Add gnome-desktop-invalid-size-crash.patch: fix a crash caused
  by a malformed background xml file (bsc#1176596
  glgo#GNOME/gnome-desktop#169).
* Fri Sep 11 2020 bjorn.lie@gmail.com
- Update to version 3.36.6:
  + No changes, version bump only.
* Mon Aug 10 2020 bjorn.lie@gmail.com
- Update to version 3.36.5:
  + No changes, version bump only.
* Wed Jul  8 2020 bjorn.lie@gmail.com
- Update to version 3.36.4:
  + tests: Don't run at build-time.
  + Updated translations.
* Mon Jun 15 2020 bjorn.lie@gmail.com
- Update to version 3.36.3.1:
  + Bump meson version.
- Changes from version 3.36.3:
  + Thumbnails: keep the original file name
  + Fix encoding issue when translating locale modifiers
  + Update wallclock reftest expectations
  + Update Hebrew wallclock expectation
  + Updated translations.
* Wed Apr 29 2020 bjorn.lie@gmail.com
- Update to version 3.36.2:
  + Updated translations.
* Wed Apr  1 2020 bjorn.lie@gmail.com
- Update to version 3.36.1:
  + Updated translations.
* Wed Apr  1 2020 bjorn.lie@gmail.com
- Update to version 3.36.0:
  + Updated translations.
* Wed Apr  1 2020 dimstar@opensuse.org
- Update to version 3.35.91:
  + Updated translations.
* Wed Apr  1 2020 dimstar@opensuse.org
- Update to version 3.35.90:
  + Fix crash in idle monitor.
- Changes from version 3.35.4:
  + Remove unused API not compatible with wayland.
- Changes from version 3.35.3:
  + Add utility function to start a transient systemd scope.
  + Honor XKB_CONFIG_ROOT environment variable.
- Changes from version 3.35.2:
  + Fix time display issue with Japanese translation.
- Rename library subpackage libgnome-desktop-3-18 to
  libgnome-desktop-3-19: Follow upstreams soname change (also in
  baselibs.conf).
* Wed Apr  1 2020 bjorn.lie@gmail.com
- Update to version 3.34.5:
  + Updated translations.
* Mon Feb 17 2020 bjorn.lie@gmail.com
- Update to version 3.34.4:
  + Don't use seccomp on riskv64.
  + Updated translations.
* Fri Jan 10 2020 bjorn.lie@gmail.com
- No longer recommend gnome-desktop-lang: the lang package has
  relevant supplements which pulls it in whenever needed.
- Move /usr/share/locale/en from the -lang package to the main
  package: English is installed on all systems. This avoids
  gnome-desktop-lang being triggered for installation on
  english-only systems.
* Wed Jan  8 2020 bjorn.lie@gmail.com
- Update to version 3.34.3:
  + Seccomp is not supported ATM on riscv64 architecture, blacklist
    it for now.
* Tue Dec  3 2019 bjorn.lie@gmail.com
- Update to version 3.34.2:
  + Add helper to create transient systemd scopes.
  + Updated translations.
- Add pkgconfig(libsystemd) BuildRequires: New dependency.
* Tue Oct  8 2019 bjorn.lie@gmail.com
- Update to version 3.34.1:
  + Updated translations.
* Tue Sep 10 2019 mgorse@suse.com
- Update to version 3.34.0:
  + Updated translations.
* Thu Sep  5 2019 mgorse@suse.com
- Update to version 3.33.92.1:
  + tests/wall*: Do not fail if some of the locales is missing.
- Changes in version 3.33.92:
  + Updated translations.
- Changes in version 3.33.91:
  + Updated translations.
- Changes in version 3.33.90:
  + Avoid using g_type_class_add_private().
  + Updated translations.
- Changes in version 3.33.4:
  + Support common_name in ISO 639.
  + Display locale @modifiers properly.
  + Fix detection of builtin display on NVIDIA.
  + GnomeBGSlideShow filename property replaced with a file
    property.
- Changes in version 3.33.3:
  + Updated translations.
- Changes in version 3.33.2:
  + thumbnailer: Correctly cleanup stale thumbnailer directories.
  + Updated translations.
- Changes in version 3.33.1:
  + gnome-languages: Use uselocale to avoid threadsafety issues.
  + Add default keyboard layout for Indonesia.
  + Updated translations.
- API version is now 18.
- Rebase gnome-desktop-switch-Japanese-default-input-to-mozc.patch.
* Tue May  7 2019 bjorn.lie@gmail.com
- Update to version 3.32.2:
  + Updated translations.
* Thu Apr 25 2019 bjorn.lie@gmail.com
- Update to version 3.32.1.2 (CVE-2019-11460):
  + Release to correct CVE ID.
* Tue Apr 23 2019 bjorn.lie@gmail.com
- Update to version 3.32.1.1:
  + Fix thumbnailer sandbox escape, CVE-2019-11460,
    glgo#GNOME/gnome-desktop#112.
* Wed Apr 10 2019 bjorn.lie@gmail.com
- Update to version 3.32.1:
  + Updated translations.
* Tue Mar 12 2019 bjorn.lie@gmail.com
- Update to version 3.32.0:
  + Stable release version bump.
* Fri Mar  8 2019 bjorn.lie@gmail.com
- Update to version 3.31.92:
  + tests: fixes to use uselocale.
  + Thumbnail: Only mount fontconfig cache if it exists.
  + Updated translations.
* Thu Feb 21 2019 bjorn.lie@gmail.com
- Update to version 3.31.91:
  + Updated translations.
- Changes from version 3.31.90:
  + Fix slow thumbnailer due to missing font cache.
  + Updated translations.
* Thu Feb  7 2019 bjorn.lie@gmail.com
- Fix translation-update-upstream call, needed after update of
  translation-update-upstream in distro.
* Thu Feb  7 2019 bjorn.lie@gmail.com
- Update to version 3.31.4:
  + Fix some thumbnailer sandboxing issues.
  + Updated translations.
* Thu Feb  7 2019 bjorn.lie@gmail.com
- Update to version 3.31.3:
  + Use LC_TIME for time format string translations.
  + Fix a use-after-free in the thumbnailer.
- Changes from version 3.31.2:
  + Updated translations.
- Changes from version 3.31.1:
  + Port buildsystem to meson.
  + Updated translations.
- Switch to meson buildsystem, add meson BuildRequires and macros.
- Drop all conditionals and gnome-common BuildRequires: they are
  not needed, nor make sense after the port to meson.
* Wed Feb  6 2019 bjorn.lie@gmail.com
- Update to version 3.30.2.1:
  + Fix slow thumbnailer due to missing font cache.
  + Updated translations.
* Sun Oct 28 2018 bjorn.lie@gmail.com
- Update to version 3.30.2:
  + Updated translations.
* Wed Sep 26 2018 bjorn.lie@gmail.com
- Update to version 3.30.1:
  + Fix another wall clock regression.
* Fri Sep 21 2018 jengelh@inai.de
- Strip pointless --with-pic, no static libs are built.
* Sat Sep  8 2018 antoine.belvire@opensuse.org
- Update to version 3.30.0:
  + Updated translations.
* Wed Aug 15 2018 bjorn.lie@gmail.com
- Update to version 3.29.91:
  + Fix various wall clock regressions.
  + Fix regressions from intltool removal.
  + Fix regressions introduced by g_autoptr usage.
* Fri Aug  3 2018 bjorn.lie@gmail.com
- Update to version 3.29.90.1:
  + wall-clock: Tweak the clock format
  + Require gio-unix-2.0.
- Changes from version 3.29.90:
  + wall-clock: Immediately react to show-weekday changes.
- Add pkgconfig(gio-unix-2.0) BuildRequires: New dependency.
- Use make_build macro.
* Sat Jul 28 2018 bjorn.lie@gmail.com
- Update to version 3.29.4:
  + No changes, version bump only.
* Tue Jun 19 2018 bjorn.lie@gmail.com
- Update to version 3.29.3:
  + Fix memory leak.
  + Updated translations.
* Fri May 11 2018 bjorn.lie@gmail.com
- Update to version 3.29.1:
  + Updated translations.
* Thu May 10 2018 bjorn.lie@gmail.com
- Update to version 3.28.2:
  + Fix a memory leak in background slide shows.
  + Updated translations.
- Drop gnome-desktop-plug-memory-leak.patch: Fixed upstream.
* Mon Apr 30 2018 bjorn.lie@gmail.com
- Add gnome-desktop-plug-memory-leak.patch: bg-slide-show: Plug a
  memory leak (bgo#793878).
* Wed Apr 11 2018 bjorn.lie@gmail.com
- Update to version 3.28.1:
  + Updated translations.
* Tue Mar 20 2018 dimstar@opensuse.org
- Unconditionally enable translation-update-upstream: on
  Tumbleweed, this results in a NOP and for Leap in SLE paid
  translations being used (boo#1086036).
* Mon Mar 12 2018 dimstar@opensuse.org
- Update to version 3.28.0:
  + No changes.
* Fri Mar  9 2018 bjorn.lie@gmail.com
- Update to version 3.27.92:
  + Idle-monitor fixes.
  + Several fixes for compilation warnings.
  + Updated translations.
* Wed Feb 28 2018 dimstar@opensuse.org
- Modernize spec-file by calling spec-cleaner
* Sat Feb 10 2018 bjorn.lie@gmail.com
- Update to version 3.27.90:
  + Miscellaneous improvements to the thumbnailer code.
  + Remove unused gnome_desktop_thumbnail_has_uri().
  + Replace GdkColor methods with GdkRGBA methods.
- Bump so name following upstream changes, ie: rename sub package
  libgnome-desktop-3-12 to libgnome-desktop-3-17 and in
  baselibs.conf.
* Wed Nov 15 2017 luc14n0@linuxmail.org
- Update to version 3.27.2:
  + No changes.
* Thu Nov  2 2017 dimstar@opensuse.org
- Update to version 3.27.1:
  + Change default Japanish input source to KCC.
  + wall-clock: respect new clock-show-weekday setting.
  + Remove some obsolete API's in thumbnailer.
  + Modernize autotools configuration a bit.
  + Updated translations.
- Rebase gnome-desktop-switch-Japanese-default-input-to-mozc.patch:
  For now we stay with mozc, despite upstream changing to kkc.
* Wed Nov  1 2017 fezhang@suse.com
- Update to version 3.26.2:
  + Updated translations.
* Wed Oct  4 2017 zaitor@opensuse.org
- Update to version 3.26.1:
  + Fix problems with thumbnailer sandboxing (bgo#787072).
  + Updated translations.
- Drop gnome-desktop-no-usr-merge.patch: Fixed upstream.
* Mon Sep 11 2017 jengelh@inai.de
- Update package summaries.
  Avoid running fdupes across hardlink boundaries.
* Mon Sep 11 2017 zaitor@opensuse.org
- Update to version 3.26.0:
  + Updated translations.
* Wed Sep  6 2017 dimstar@opensuse.org
- Update to version 3.25.92:
  + Fix multiple bugs in thumbnailing.
  + Disable gvfs in thumbnailer sandboxes.
  + Updated translations.
* Sat Sep  2 2017 qzhao@suse.com
- Add gnome-desktop-switch-Japanese-default-input-to-mozc.patch:
  Switch new user's default input engine from "anthy" to "mozc" in
  gnome-desktop with Japanese language and ibus input frame-work
  (bnc#1029083, boo#1056289).
* Fri Sep  1 2017 dimstar@opensuse.org
- Add gnome-desktop-no-usr-merge.patch: Also link /lib and /lib64
  into the bubblewrap container, as we do not (yet) have all the
  libs in /usr.
- Add bubblewrap dependency to libgnome-desktop-3-12.
* Wed Aug 23 2017 zaitor@opensuse.org
- Update to version 3.25.91.1:
  + Fix multiple bugs in sandboxed thumbnailer handling, including
    performance, and left-over files in /tmp.
  + Fix a memory leak in the display handling code.
  + Fix a compile-time error on x32.
- Changes from version 3.25.90.1:
  + Improve error reporting in thumbnailers.
  + Fix crashes in thumbnailers (bgo#785963).
* Mon Aug  7 2017 zaitor@opensuse.org
- Update to version 3.25.90:
  + Thumbnailers are now sandboxed (bgo#7744970, bgo#785197).
  + Fix a crash in xkb info handling (bgo#785320).
  + Updated translations.
- Add pkgconfig(libseccomp) BuildRequires: New dependency.
* Thu Jul 20 2017 zaitor@opensuse.org
- Update to version 3.25.4:
  + Fix uninitialized memory in the thumbnailer (bgo#784915).
  + Add default input source for fr_BE.
* Tue Jun 20 2017 dimstar@opensuse.org
- Update to version 3.25.3:
  + gnome-bg: Handle exif orientations (bgo#516177).
  + Updated translations.
* Tue May 23 2017 zaitor@opensuse.org
- Update to version 3.25.2:
  + thumbnail: Update documentation.
* Sat May 20 2017 zaitor@opensuse.org
- Update to version 3.25.1:
  + wallclock:
  - Don't update needlessly (bgo#780861).
  - am/pm is always available now (bgo#780877).
  + Updated translations.
* Wed May 10 2017 zaitor@opensuse.org
- Update to version 3.24.2:
  + No changes, stable version bump only.
* Mon Apr 24 2017 dimstar@opensuse.org
- Update to version 3.24.1:
  + Updated translations.
* Tue Mar 21 2017 zaitor@opensuse.org
- Update to version 3.24.0:
  + No changes.
* Tue Mar 14 2017 dimstar@opensuse.org
- Update to version 3.23.92:
  + No changes.
* Mon Feb 27 2017 zaitor@opensuse.org
- Update to version 3.23.91:
  + No changes.
* Wed Feb 15 2017 dimstar@opensuse.org
- Update to version 3.23.90:
  + Always prefer the backend-provided preview in thumbnails
    (bgo#738503).
  + Use ibus-libzhuyin as default input method for Simplified
    Chinese (bgo#772674).
  + Deprecated gnome_desktop_thumbnail_scale_down_pixbuf
    (bgo#775991).
* Tue Dec 13 2016 dimstar@opensuse.org
- Update to version 3.23.3:
  + Always use external gdk-pixbuf thumbnailer (bgo#768064).
* Tue Nov 22 2016 dimstar@opensuse.org
- Update to version 3.23.2:
  + No changes.
* Wed Nov  9 2016 dimstar@opensuse.org
- Update to version 3.23.1:
  + No changes.
* Mon Nov  7 2016 dimstar@opensuse.org
- Update to version 3.22.2:
  + Updated translations.
* Mon Oct 10 2016 zaitor@opensuse.org
- Update to version 3.22.1:
  + Updated translations.
- Conditionally apply translations-update-upstream BuildRequires
  and macro for non-openSUSE only.
- Stop passing V=1 to make, we do debugging locally.
* Mon Sep 19 2016 zaitor@opensuse.org
- Update to version 3.22.0:
  + No changes, pure versionbump.
* Tue Sep 13 2016 zaitor@opensuse.org
- Update to version 3.21.92:
  + Fix a crash on non-udev platforms (bgo#770686).
  + Updated translations.
* Tue Aug 16 2016 zaitor@opensuse.org
- Update to version 3.21.90:
  + No changes, pure versionbump.
* Sat Jul 23 2016 zaitor@opensuse.org
- Update to version 3.21.4:
  + Use udev's hwdb to query PNP IDs (--disable-udev to disable
    this).
  + Remove dependencies on xrandr and xext.
- Following upstream changes, remove pkgconfig(xext) and
  pkgconfig(xrandr) and add pkgconfig(libudev) BuildRequires.
- Drop gnome-desktop-bnc896687-benq-pnp-id.patch: Not needed
  anymore since the switch to udev's hwdb.
* Tue Jun 21 2016 zaitor@opensuse.org
- Update to version 3.21.3:
  + Updated translations.
- Drop gnome-about obsoletes: gnome-about have not been around
  since before GNOME 3.0, it's about time we drop it.
* Sat May 28 2016 zaitor@opensuse.org
- Update to version 3.21.2:
  + Add API to know if a GnomeRRMode is interlaced.
* Thu May 26 2016 federico@suse.com
- Update to GNOME 3.20.2  Fate#318572
* Tue May 10 2016 zaitor@opensuse.org
- Update to version 3.20.2:
  + No changes.
* Wed Apr 13 2016 idonmez@suse.com
- Update to GNOME 3.20  Fate#318572
- Refresh gnome-desktop-bnc896687-benq-pnp-id.patch
- Remove upstream patches:
  + bnc952146-wall-clock-replace-ratio-with-colon-on-non-UTF-8-locales.patch
  + gnome-desktop-bgo706229-mouse-cursor.patch
  + gnome-desktop-bgo719428-fix-leak.patch
  + gnome-desktop-bgo719928-display-name.patch
* Tue Apr 12 2016 dimstar@opensuse.org
- Update to version 3.20.1:
  + No changes.
* Mon Mar 21 2016 dimstar@opensuse.org
- Update to version 3.20.0:
  + No changes.
* Thu Mar 17 2016 dimstar@opensuse.org
- Update to version 3.19.93:
  + Add a way to get the frequency for a mode as a floating number.
* Mon Mar 14 2016 dimstar@opensuse.org
- Update to version 3.19.92:
  + Only version update.
* Thu Mar  3 2016 zaitor@opensuse.org
- Update to version 3.19.91:
  + Reduce log spam in thumbnailing.
  + Updated translations.
* Tue Feb 16 2016 dimstar@opensuse.org
- Update to version 3.19.90:
  + Only version update.
- Changes from version 3.19.4:
  + Capitalize language and territory names.
  + Add default keyboard layout for Mexico and Guatemala.
  + Avoid a crash when thumbnailing.
  + Be more careful when parsing locales.
  + Updated translations.
* Sat Dec 19 2015 damjanovic.ivo@gmail.com
- Update to version 3.19.3:
  + Fixed compiler warning in gnome-rr.
* Tue Nov 24 2015 zaitor@opensuse.org
- Update to version 3.19.2:
  + Updated translations.
* Tue Nov 24 2015 zaitor@opensuse.org
- Update to version 3.19.1:
  + Fix turning off tiled monitors.
  + Fix thumbnailing of animations.
  + Updated translations.
* Mon Nov  9 2015 zaitor@opensuse.org
- Update to version 3.18.2:
  + Updated translations.
* Fri Oct 30 2015 cxiong@suse.com
- Added
  bnc952146-wall-clock-replace-ratio-with-colon-on-non-UTF-8-locales.patch
  (bnc#952146, bgo#722664).
* Mon Oct 12 2015 zaitor@opensuse.org
- Update to version 3.18.1:
  + Drop unneeded includes.
  + gnome-rr: Fix turning off tiled monitors.
  + Updated translations.
* Mon Sep 21 2015 dimstar@opensuse.org
- Update to version 3.18.0:
  + Updated translations.
* Wed Sep 16 2015 dimstar@opensuse.org
- Update to version 3.17.92:
  + Support g_autoptr() for all libgnome-desktop object types.
* Thu Sep  3 2015 zaitor@opensuse.org
- Update to version 3.17.91:
  + Updated translations.
* Tue Aug 18 2015 zaitor@opensuse.org
- Update to version 3.17.90:
  + Updated translations.
* Thu Jul 23 2015 zaitor@opensuse.org
- Update to version 3.17.4:
  + Remove unused EDID parsing code.
  + Support underscanning.
  + Export dpms information.
  + Add support for tiled monitors.
  + Updated translations.
- Bump libgnome-desktop soname and rename subpackage (also in
  baselibs.conf) following upstreams changes.
* Fri Jun 26 2015 zaitor@opensuse.org
- Update to version 3.17.3:
  + Fix build of installed-tests.
  + Updated translations.
* Wed May 27 2015 zaitor@opensuse.org
- Update to version 3.17.2:
  + Add support for overscan compensation in displays (bgo#748560).
* Tue May 12 2015 zaitor@opensuse.org
- Update to version 3.16.2:
  + No changes.
* Wed Apr 29 2015 federico@suse.com
- Added gnome-desktop-bnc896687-benq-pnp-id.patch for bnc#896687 -
  list BenQ monitors in pnp.ids.
* Wed Apr 15 2015 dimstar@opensuse.org
- Update to version 3.16.1:
  + No changes.
* Mon Mar 23 2015 dimstar@opensuse.org
- Update to version 3.16.0:
  + Updated translations.
* Tue Mar 17 2015 dimstar@opensuse.org
- Update to version 3.15.92:
  + Updated translations.
* Tue Mar  3 2015 dimstar@opensuse.org
- Update to version 3.15.91:
  + No changes.
* Mon Feb 16 2015 dimstar@opensuse.org
- Update to version 3.15.90:
  + Drop libgsystem dependency (bgo#680326).
  + Updated translations.
* Mon Jan 26 2015 badshah400@gmail.com
- Update to version 3.15.4:
  + Modernize gtk-doc use (bgo#742479).
  + Fix memory handling in GnomeRR and language code (bgo#742111,
    bgo#742569).
* Wed Dec 17 2014 zaitor@opensuse.org
- Update to version 3.15.3:
  + Fix mutex handling in thumbnailing code (bgo#740666).
* Wed Dec 17 2014 zaitor@opensuse.org
- Update to version 3.15.2.1:
  + Fix thumbnailing failures due to internal cleanups
    (bgo#684026).
* Tue Nov 18 2014 zaitor@opensuse.org
- Update to version 3.15.1:
  + languages: Use a more broadly compatible locale codeset suffix
    (bgo#710412).
  + Updated translations.
* Thu Nov 13 2014 zaitor@opensuse.org
- Update to version 3.14.2:
  + tests: Remove unused code in gtk-reftest (bgo#737123).
  + Updated translations.
* Tue Oct 14 2014 dimstar@opensuse.org
- Update to version 3.14.1:
  + Updated translations.
* Mon Sep 22 2014 zaitor@opensuse.org
- Update to version 3.14.0:
  + Updated translations.
* Mon Sep 15 2014 zaitor@opensuse.org
- Update to version 3.13.92:
  + Fixed the build on systems lacking openat().
  + Updated translations.
* Sun Sep  7 2014 zaitor@opensuse.org
- Update to version 3.13.91:
  + gnome-xkb-info: Fix some layouts not being associated to a
    locale.
  + Updated translations.
* Thu Aug 21 2014 dimstar@opensuse.org
- Update to version 3.13.90:
  + gnome-rr: Add missing introspection annotations.
  + Updated translations.
* Wed Jul 23 2014 dimstar@opensuse.org
- Update to version 3.13.4:
  + Bump version for the 3.13.4 release. No other changes.
* Sat Jul 12 2014 dimstar@opensuse.org
- Update to version 3.13.3:
  + wall-clock: Add ref-tests for clock output.
  + wall-clock: Always use the ratio character (bgo#726232).
- Changes from version 3.13.2:
  + gnome-rr: Output the EDID vendor/product info as well.
  + gnome-rr: Add backlight output in debug.
  + thumbnailer: Try harder to create a failed thumbnail
    (bgo#728775).
* Sat May 17 2014 zaitor@opensuse.org
- Update to version 3.13.1:
  + Fix the build on OpenBSD.
  + gnome-rr: Improve debug output.
- Stop passing obsolete --disable-scrollkeeper to configure.
* Sat May 17 2014 zaitor@opensuse.org
- Update to version 3.12.2:
  + gnome-rr: Better debug application.
* Wed Apr 16 2014 zaitor@opensuse.org
- Update to version 3.12.1:
  + gnome-rr:
  - Actually define output_get_possible_crtcs (bgo#727034).
  - Initialize GnomeRROutputInfo:rotation to GNOME_RR_ROTATION_0
    (bgo#727023).
* Thu Mar 27 2014 mgorse@suse.com
- Add gnome-desktop-bgo706229-mouse-cursor.patch: fix sometimes
  invisible mouse cursor.
- Add gnome-desktop-bgo719428-fix-leak.patch: Fix a GHashTable
  leak.
- Add gnome-desktop-bgo719928-display-name.patch: Have gnome-rr
  copy the display name.
* Mon Mar 24 2014 dimstar@opensuse.org
- Update to version 3.12.0:
  + Version bump for the GNOME 3.12.0 stable release.
* Wed Mar 19 2014 dimstar@opensuse.org
- Update to version 3.11.91:
  + Always set the DPMS mode when requested.
  + Updated translations.
* Wed Feb 19 2014 zaitor@opensuse.org
- Update to version 3.11.90:
  + gnome-xkb-info:
  - Remove xkbfile dependency. API and ABI break (bgo#719942).
  - Apply main layout locale metadata to variants (bgo#711291).
- Rename libgnome-desktop-3-8 to libgnome-desktop-3-10 and make
  corresponding changes to post/postun calls following upstream
  soname bump (also in baselibs.conf).
* Mon Feb  3 2014 dimstar@opensuse.org
- Update to version 3.11.5:
  + Wall-clock: Replace ratio with colon on non-UTF-8 locales
    (bgo#722664).
* Fri Jan 17 2014 zaitor@opensuse.org
- Update to version 3.11.4:
  + More new gnome-rr api.
  + Drop using glibc internal headers.
  + Docs for thumbnailers.
  + Idle monitor fixes.
  + Use newer libgsystem internally.
* Fri Nov 22 2013 dimstar@opensuse.org
- Update to version 3.11.2:
  + gnome-rr: Improve debug output.
  + Updated translations.
* Fri Nov 22 2013 dimstar@opensuse.org
- Update to version 3.11.1:
  + Add gnome_rr_output_get_min_backlight_step() API.
* Thu Nov 21 2013 dimstar@opensuse.org
- Update to version 3.10.2 (bnc#849913):
  + Updated translations.
* Tue Oct 15 2013 dimstar@opensuse.org
- Update to version 3.10.1:
  + gnome-bg:
  - Fix memory leaks (bgo#709271).
  - set error when parsing XML file that's not a slide show
    (bgo#708877).
  + languages: Obtain supported locales from "locale -a" output
    (bgo#698383).
  + thumbnailer:
  - Bail if no pixbuf loader could be created (bgo#709819).
  - Support loading thumbnails from remote locations
    (bgo#708824).
  + Updated translations.
* Tue Sep 24 2013 dimstar@opensuse.org
- Update to version 3.10.0:
  + libsystem: Update from master (bgo#708435).
  + gnome-rr: refresh when mutter restarts (bgo#708284).
  + Updated translations.
* Wed Sep 18 2013 dimstar@opensuse.org
- Update to version 3.9.92:
  + IdleMonitor: protect watches from being freed while in flight
    (bgo#707396).
  + Thumbnailer:
  - Always print errors from gs_file_read_noatime() (bgo#699252).
  - Correctly check for errors (bgo#699252).
  - Check gdk_pixbuf_loader_close()'s retval (bgo#699252).
  + Correct the transposed bits of the red chromacity in the EDID
    parser.
  + Updated translations.
* Tue Sep  3 2013 dimstar@opensuse.org
- Update to version 3.9.91:
  + gnome-rr: don't assume 'default' means built-in (bgo#706738).
  + gnome-rr: Read back new backlight value after changes
    (bgo#706729).
  + idle: Use mutter api instead of direct X calls (bgo#706006).
  + Updated translations.
- Rename libgnome-desktop-3-7 subpackage to libgnome-desktop-3-8,
  following upstreams soname bump (also in baselibs.conf).
* Tue Aug 20 2013 dimstar@opensuse.org
- Update to version 3.9.90:
  + gnome-rr: Add api to get physical size.
  + gnome-rr: Add async constructor.
  + gnome-rr: Port to mutter dbus api (bgo#705510).
  + xkb: Prevent a crash (bgo#705885).
  + Updated translations.
* Tue Jul 30 2013 dimstar@opensuse.org
- Update to version 3.9.5:
  + xkb: Ensure strings are UTF-8.
  + gnome-rr: Fix a crash.
  + gnome-rr: Be more careful when parsing EDID.
  + wall-clock: Initialize gettext.
  + gnome-bg: Objects without a filename are not slideshows.
  + gnome-xkb-info: Fix memory leaks.
  + Updated translations.
* Thu May 30 2013 dimstar@opensuse.org
- Update to version 3.9.1.1:
  + gnome-xkb-info: Don't store duplicated layouts in locale
    tables.
  + idle-monitor: Make per-device monitor fallible.
  + idle-monitor: Allow multiple watches per alarm.
  + wall-clock: Move ratio from msg id's to translations.
  + Updated translations.
* Tue May 14 2013 dimstar@opensuse.org
- Update to version 3.8.2:
  + Fix a memory leak (bgo#695116).
  + Add some more defaults for input sources.
  + Updated translations.
* Mon Apr 15 2013 dimstar@opensuse.org
- Update to version 3.8.1:
  + Updated translations.
* Wed Mar 27 2013 dimstar@opensuse.org
- Update to version 3.8.0.1:
  + Fix a potential use-after-free corruption and crash
    (bgo#696719).
* Wed Mar 27 2013 dimstar@opensuse.org
- Update to version 3.8.0:
  + idle-monitor:
  - Allow multiple watches per alarm (bgo#696522).
  - Make per-device monitor fallible (bgo#696118).
  + Updated translations.
* Tue Mar 19 2013 dimstar@opensuse.org
- Update to version 3.7.92:
  + Don't store duplicated layouts in locale tables.
  + Updated translations.
* Wed Mar  6 2013 dimstar@opensuse.org
- Update to version 3.7.91.1:
  + GnomeBg:
  - remove ability to not draw background (bgo#690378).
  + GnomeRR:
  - use 'Built-in Display' instead of 'Laptop' (bgo#679794).
  + Updated translations.
* Tue Feb 19 2013 dimstar@opensuse.org
- Update to version 3.7.90:
  + Fix introspection generation for Vala.
  + Fix introspectability of GnomeBg.
  + GnomeIdleMonitor:
  - Break ABI and API to fix reliance of the API on an Xorg bug.
  - use standard GObject boilerplate.
  - generate gtk-doc documentation.
  + GnomeWallClock:
  - generate gtk-doc documentation.
  - add timezone property which can be monitored.
  - Add conventional gnome_wall_clock_new().
  + GnomeXkbInfo:
  - generate gtk-doc documentation.
  - Use the correct methods to get language/country.
  - Handle duplicated layouts.
  - Add API to get layouts for language and country.
  + gnome-languages:
  - generate gtk-doc documentation.
  - Add methods to get language/country from ISO codes.
  - Add default input sources per locale.
  + GnomeRR:
  - Make GnomeRRConfig use the detected display name.
  - use standard GObject boilerplate.
  - Improve gtk-doc documentation.
  + GnomeBg:
  - Split slide show API to be usable from gnome-shell.
  - Add asynchronous version of slideshow loading.
* Tue Feb  5 2013 dimstar@opensuse.org
- Update to version 3.7.5:
  + languages:
  - Don't g_warning if there's no locale archive.
  - Extracted from gnome-control-center.
  - Fix a memory leak.
  + xkb-info:
  - Group layouts by country and language.
  - Add a get_layout_info_for_locale method.
  + Updated translations.
- Add pkgconfig(iso-codes) BuildRequires: new dependency.
* Tue Jan 15 2013 dimstar@opensuse.org
- Update to version 3.7.4:
  + wallclock: Fix AM/PM detection (bgo#690703)
  + wallclock: return a proper error when idle-counter unavailable
  + GnomeRR: make DPMS take effect immediately (bgo#691701)
  + Updated translations.
* Tue Jan  8 2013 dimstar@opensuse.org
- Update to version 3.7.3:
  + rr-labeler has been moved into gnome-control-center.
  + We use nice Unicode for date formatting now.
  + idle-monitor: Reset the alarm so it can be triggered again
    (bgo#688227).
  + Updated translations.
- Rename libgnome-desktop-3-4 subpackage to libgnome-desktop-3-5,
  following upstram soname bump (also in baselibs.conf).
* Sun Nov 25 2012 dimstar@opensuse.org
- Update to version 3.7.2:
  + Bugs fixed: bgo#682224, bgo#682224, bgo#688189, bgo#687913.
  + Updated translations.
* Wed Nov 14 2012 dimstar@opensuse.org
- Update to version 3.7.1:
  + Bugs fixed: bgo#684814, bgo#684803, bgo#682224, bgo#686792.
  + Updated translations.
* Tue Nov 13 2012 dimstar@opensuse.org
- Update to version 3.6.2:
  + gnome-rr: Fall back to XFree86_DDC_EDID1_RAWDATA.
  + Updated translations.
* Wed Oct 17 2012 zaitor@opensuse.org
- Update to version 3.6.1:
  + wall-clock:
  - Add test application.
  - Add debug when timezone or schema changes.
  + rr-labeler:
  - Clear surface before drawing frame and background.
  - Use a shape region if the widget is not composited.
  - Scale the corner radii when drawing the fill.
  + Updated translations.
* Tue Sep 25 2012 dimstar@opensuse.org
- Update to version 3.6.0.1:
  + gnome-xkb-info: Fix introspection element-type annotations
    (bgo#684802).
* Mon Sep 24 2012 dimstar@opensuse.org
- Update to version 3.6.0:
  + gnome-xkb-info: Fix a memory leak (bgo#684140)
  + Updated translations.
* Fri Sep  7 2012 vuntz@opensuse.org
- Remove %%IS_DEFAULT_GNOME_DESKTOP conditionals for everything
  related to the documentation: now that they were ported to
  yelp-tools, they can't conflict with some old GNOME 2 docs.
- Remove libgnome-desktop-3-2 Conflicts in
  libgnome-desktop-3_0-common: the file conflict is now gone (with
  the port to yelp-tools), and since we never had this new package
  in Factory, the Conflicts is useless.
* Tue Sep  4 2012 dimstar@opensuse.org
- Update to version 3.5.91:
  + gnome-xkb-info: Honor the 'show-all-sources' gsettings key
    (bgo#682240)
  + Make 'Mirrored Displays' string consistent with the
    control-center (bgo#592412)
  + Thumbnails: Determine the correct mime type when we still know
    the filename (bgo#655406)
  + Remove the temporary file when saving a thumbnail fails and
    show an error when saving a thumbnail fails (bgo#681942)
  + Updated translations.
* Wed Aug 22 2012 dimstar@opensuse.org
- Update to version 3.5.90:
  + GnomeBG:
  - Fix crash if default background not found
  - Don't use C99 declarations
  + Import libgsystem and use it to read thumbnails with O_NOATIME
  + gnome-xkb-info:
  - Parse XKB options
  - Use glib's slice allocator for small structures
  + Increase the size of thumbnails to 256
  + Bugs fixed: bgo#680326, bgo#680354, bgo#681897, bgo#681929,
    bgo#682004, bgo#682252.
  + Updated translations.
* Wed Aug 15 2012 dimstar@opensuse.org
- Split out a libgnome-3_0-common package containing the data
  files. Having them in the library package hinders parallel
  installability of more than one libgnome-desktop package. This
  package conflicts with libgnome-desktop-3-2 because of common
  files.
* Tue Aug  7 2012 dimstar@opensuse.org
- Update to version 3.5.5:
  + Update to new GMutex API
  + GnomeWallClock: add ignore-date property
  + Port to new documentation infrastructure
  + gnome-bg: load the default background if the configured one is
    invalid
  + Updated translations.
- Replace gnome-doc-utils-devel BuildRequires with yelp-tools,
  following upstreams switch to the new documentation
  infrastructure.
- Drop special handling for openSUSE 11.1, 11.2 and 11.3: they are
  end of life.
* Tue Jul 17 2012 dimstar@opensuse.org
- Update to version 3.5.4:
  + Fix many documentation syntax warnings.
  + Bugs fixed: bgo#672030, bgo#679858.
* Tue Jun 26 2012 dimstar@opensuse.org
- Update to version 3.5.3:
  + gnome-bg:
  - Fix color conversion for solid backgrounds
  - Force property update when doing new crossfade frame
  + gnome-rr:
  - Add gnome_rr_output_get_ids_from_edid()
  - Document the default DPI setting
  - Revert "Allow rotation if the virtual size has the correct
    number of pixels"
  + pnp-ids:
  - Add test program
  - Add loop for speed testing the ID fetching
  + Move thumbnails into XDG_CACHE_HOME
  + Updated translations.
* Fri Jun  8 2012 dimstar@opensuse.org
- Update to version 3.5.2:
  + Add api to parse and describe XML layouts (bgo#676583)
  + Make monitor labels translucent and click-through (bgo#675696)
  + Fix a crash in background slide-shows when the system clock is
    behind (bgo#673551)
  + Use "default" as the name for built-in laptop outputs
    (bgo#949296)
  + Add a gnome-rr-debug tool to help with debugging GnomeRR issues
  + Updated translations.
- Add libxkbfile-devel Requires in devel subpackage, as headers
  from there are used.
* Mon May 14 2012 vuntz@opensuse.org
- Update to version 3.4.2:
  + GnomeBG: Fix crash when system clock is behind start date
* Tue Apr 17 2012 vuntz@opensuse.org
- Update to version 3.4.1:
  + Updated translations.
* Mon Mar 26 2012 vuntz@opensuse.org
- Update to version 3.4.0:
  + Updated translations.
* Mon Mar 19 2012 zaitor@opensuse.org
- Update to version 3.3.92:
  + libgnome-desktop:
  - GnomeBG:
    . Publish the 'representative color'.
    . Code cleanups.
  - GnomeRR:
    . Add definition for next rotation.
    . Detect Apple DFP outputs as internal.
  + Updated translations.
* Mon Mar  5 2012 vuntz@opensuse.org
- Update to version 3.3.91:
  + libgnome-desktop:
  - Add missing linking with -lrt for clock_gettime()
  - GnomeRR: Consider Embedded Display Port outputs as the
    laptop's built-in display
  + Updated translations.
* Tue Feb 21 2012 vuntz@opensuse.org
- Update to version 3.3.90:
  + libgnome-desktop:
  - GnomeBG: Add paranoid check to avoid crash
  + Updated translations.
- Remove xz BuildRequires now that it comes for free in the build
  system.
* Mon Feb  6 2012 vuntz@opensuse.org
- Update to version 3.3.5:
  + Include exported pkg-config name in GIR.
  + Updated translations.
* Mon Jan 16 2012 vuntz@opensuse.org
- Update to version 3.3.4:
  + libgnome-desktop:
  - GnomeRR:
    . Use GDK to get work area
    . gnome_rr_screen_new() now creates a singleton for the
    specified GdkScreen
* Tue Dec 20 2011 vuntz@opensuse.org
- Update to version 3.3.3:
  + No change, just a version bump.
- Add xz BuildRequires because we can't build a package for a
  xz-compressed tarball without explicitly specifying that... See
  bnc#697467 for more details.
- Remove unneeded text from descriptions.
* Thu Dec  8 2011 dimstar@opensuse.org
- Split typelib file into typelib-1_0-GnomeDesktop-3_0 subpackage.
- Add typelib-1_0-GnomeDesktop-3_0 Requires to devel subpackage.
* Mon Nov 21 2011 dimstar@opensuse.org
- Update to version 3.3.2:
  + libgnome-desktop:
  - GnomeRR: Don't refresh the GnomeRRScreen when applying a
    matched configuration from a file.
* Wed Oct 26 2011 dimstar@opensuse.org
- Update to version 3.3.1:
  + GnomePnpIds: Add object to get the vendor name from PNP IDs
  + GnomeRR:
  - Fix crash in update_brightness_limits
  - Don't print an error for no backlight
  - Remove deprecated functions
  - When setting the DPMS mode manually, clear the timeouts
  - Ignore DPMSSetTimeouts() and DPMSForceLevel() return value
  - Other DPMS-related fixes
  + GnomeWallClock:
  - Remove the date/time source on dispose
  - Fix non-Linux fallback code
- Really drop gnome-desktop-gnome-wall-clock-crash.patch.
* Sun Oct 16 2011 vuntz@opensuse.org
- Update to version 3.2.1:
  + libgnome-desktop
  - GnomeRR:
    . When setting the DPMS mode manually, clear the timeouts
    . Ignore DPMSSetTimeouts() and DPMSForceLevel() return value
  - GnomeWallClock: Fix non-Linux fallback code
  + Updated translations.
* Mon Sep 26 2011 vuntz@opensuse.org
- Update to version 3.2.0:
  + Updated translations.
* Tue Sep 20 2011 vuntz@opensuse.org
- Update to version 3.1.92:
  + libgnome-desktop
  - GnomeRR:
    . Fix crash in update_brightness_limits
    . Don't print an error for no backlight
  - GnomeWallClock: Remove the date/time source on dispose
  + Updated translations.
- Drop gnome-desktop-gnome-wall-clock-crash.patch: fixed upstream.
* Fri Sep  9 2011 vuntz@opensuse.org
- Add gnome-desktop-gnome-wall-clock-crash.patch: fix an issue
  leading to a gnome-screensaver crash.
* Mon Sep  5 2011 vuntz@opensuse.org
- Update to version 3.1.91:
  + libgnome-desktop:
  - Add GnomeWallClock
* Wed Aug 31 2011 vuntz@opensuse.org
- Update to version 3.1.90.1:
  + Misc
  - Link against libm
* Tue Aug 30 2011 vuntz@opensuse.org
- Update to version 3.1.90:
  + libgnome-desktop:
  - Remove GnomeTzMonitor
* Fri Aug 12 2011 dimstar@opensuse.org
- Update to version 3.1.5:
  + libgnome-desktop:
  - GnomeRR: Fix settings the DPMS mode.
* Mon Jul 25 2011 vuntz@opensuse.org
- Update to version 3.1.4:
  + libgnome-desktop
    + GnomeRR: Add the capability to get and set the DPMS mode of
    the screen
  + Misc
    + Fix Cflags path in uninstalled.pc file
    + Remove stale startup-notification dependency
    + Require xext in configure
  + Updated translations.
- Remove now unneeded pkgconfig(libstartup-notification-1.0)
  BuildRequires.
- Add pkgconfig(xext) BuildRequires, for new dependency.
* Mon Jul  4 2011 vuntz@opensuse.org
- Update to version 3.1.3:
  + libgnome-desktop:
  - GnomeRR: Add methods to control the backlight on each output
  + Misc:
  - Modernize build system a bit
  + Updated translations.
* Tue Jun 14 2011 vuntz@opensuse.org
- Update to version 3.1.2:
  + libgnome-desktop:
  - GnomeDesktopThumbnail: Use GOnce for thread safety
  - GnomeRR: Add a size return value to
    gnome_rr_output_get_edid_data()
  - GnomeRR: Emit ::output-connected and ::output-disconnected
    when screen outputs come and go
  + Updated translations.
- Rename libgnome-desktop-3-0 to libgnome-desktop-3-2, following
  library soversion change (also in baselibs.conf).
* Tue May 17 2011 dimstar@opensuse.org
- Update to version 3.1.1:
  + libgnome-desktop:
  - GnomeRR: Fix crash whden randr is not available
  - GnomeRR: Add ability to show and hide the monitor labels
  + Updated translations.
* Wed Apr 27 2011 fcrozat@novell.com
- Update to version 3.0.1:
  + Updated translations.
* Fri Apr 22 2011 vuntz@opensuse.org
- Move gnome-about Obsoletes to gnome-version subpackage as this is
  really the one providing the same kind of data.
* Tue Apr 12 2011 dimstar@opensuse.org
- Set IS_DEFAULT_GNOME_DESKTOP to 1 and add gnome-about Obsoletes
  to libgnome-desktop-3-0.
* Tue Apr  5 2011 fcrozat@novell.com
- Update to version 3.0.0:
  + libgnome-desktop:
  - GnomeRR: Fix build when randr is not available
  - GnomeRR: Avoid a crash with spice client
  + Updated translations.
* Thu Mar 24 2011 fcrozat@novell.com
- Update to version 2.91.93:
  + libgnome-desktop:
  - Revert "Force property update when doing new crossfade frame"
* Tue Mar 22 2011 fcrozat@novell.com
- Update to version 2.91.92:
  + libgnome-desktop:
  - Force property update when doing new crossfade frame
  - Use picture-uri GSettings key
  + Misc:
  - Don't build some RANDR code if RANDR is not available
  + Updated translations.
- Changes from version 2.91.91:
  + libgnome-desktop:
  - Introspection build improvement
  + Bump GTK+ 3 requirement to 3.0
  + Updated translations.
- Changes from version 2.91.90:
  + libgnome-desktop:
  - GnomeRR: Fix refcount issues in GnomeRRLabeler
  - GnomeBG: Fix background cache
  - GnomeBG: Better support for one-slide slideshows, for image
    with multiple sizes
  - GnomeRR: Properly position GnomeRRLabeler labels
  + Build fix
  + Updated translations.
* Sun Feb 13 2011 vuntz@opensuse.org
- Update to version 2.91.6.1:
  + Do not require gconf to build introspection data.
  + Updated translations.
- Drop gnome-desktop-gir-no-gconf.patch: fixed upstream.
- Remove unneeded update-desktop-files BuildRequires as there are
  no desktop files anymore.
- Pass %%{?no_lang_C} to %%find_lang so that english documentation
  can be packaged with the program, and not in the lang subpackage.
- Change Requires of lang subpackage to Recommends, since the
  english documentation is not there anymore.
* Fri Jan 14 2011 vuntz@opensuse.org
- Remove pkgconfig(gconf-2.0) BuildRequires: it's all ported to
  GSettings now.
- Add gobject-introspection-devel BuildRequires to build
  introspection data.
- Add gnome-desktop-gir-no-gconf.patch to fix build of
  introspection data. Taken from git.
- Add back --disable-date-in-gnome-version and
  - -with-gnome-distributor="SUSE" to configure: gnome-version.xml
  is back.
- Do not build the gnome-version subpackage if
  IS_DEFAULT_GNOME_DESKTOP is 0, unless BUILD_FROM_VCS is defined.
* Wed Jan 12 2011 fcrozat@novell.com
- Update to version 2.91.6:
  + libgnome-desktop:
  - Prevent gnome-settings-daemon from crashing at startup
  + Misc:
  - Add back gnome-version.xml.
- Changes from version 2.91.5:
  + libgnome-desktop:
  - gnome-desktop-utils has been ported to GSettings (bgo#638169)
  - GnomeRRScreen, GnomeRRConfig and GnomeOutputInfo have been
    turned into a GObjects (bgo#630913).
  - The GnomeRR api is introspectable now
  - Switch thumbnailers from GConf to key files (bgo#638172)
  + Updated translations.
- Add support for source service checkout, with %%BUILD_FROM_VCS:
  + Add call to ./autogen.sh (if present)
  + Enforce gtk-doc html generation by passing --enable-gtk-doc to
    configure.
  + Add gnome-common, gtk-doc BuildRequires.
- Create a gnome-version subpackage to contain the xml file with
  the GNOME version.
* Fri Jan  7 2011 vuntz@opensuse.org
- Update to version 2.91.4:
  + Remove gnome-about: a System Information panel in
    gnome-control-center replaces it.
  + libgnome-desktop:
  - Adapt to GTK+ 3 changes.
  + Misc
  - Don't export private symbols in the shared library.
  + Updated translations.
- Drop gnome-desktop-gdk_functions.patch: fixed upstream.
- Drop gnome-desktop-desktop.patch: gnome-about got removed.
- Remove gnome-about packaging (that was disabled via
  IS_DEFAULT_GNOME_DESKTOP): gnome-about got removed.
- Do not pass --disable-date-in-gnome-version and
  - -with-gnome-distributor="SUSE" to configure: the options don't
  exist anymore.
* Tue Dec 14 2010 vuntz@opensuse.org
- Stop removing kg locale on 11.4 and later: bnc#659001 has been
  fixed.
* Tue Dec 14 2010 dimstar@opensuse.org
- Add gnome-desktop-gdk_functions.patch to fix build with latest
  gtk3. Patch from upstream git, commit 260f6d, 24863a & ff299b.
* Sat Dec 11 2010 vuntz@opensuse.org
- Remove some locales until bnc#659001 is fixed, to fix a build
  failure.
* Mon Dec  6 2010 vuntz@opensuse.org
- Add gsettings-desktop-schemas Requires to libgnome-desktop-3-0,
  since applications using the library don't have to know that
  gsettings-desktop-schemas is required.
* Fri Nov 26 2010 dimstar@opensuse.org
- Update to version 2.91.3:
  + Add API to ensure primary display is set in config
  + Add cache for resized wallpapers (to help CPU usage on startup)
  + Remove gconf-2.0 from pkg-config files
- Changes frm version 2.91.2:
  + Build System fixes
  + Fix possible double-free when destroying private windows
  + Updated translations.
* Mon Nov 15 2010 dimstar@opensuse.org
- Update to version 2.91.1:
  + libgnome-desktop:
  - GnomeRR: Make the RR labels honor workarea so they don't
    appear over/under panels
  - bgo#629168: Don't read past the end of a string
  - GnomeBG: Port to GSettings
  + Misc:
  - Require gconf in pc file
  + Updated translations.
- Add pkgconfig(gsettings-desktop-schemas) BuildRequires.
* Mon Oct 11 2010 vuntz@opensuse.org
- Update baselibs.conf to not reference non-existing gnome-desktop.
* Tue Oct  5 2010 vuntz@opensuse.org
- Update to version 2.91.0:
  + libgnome-desktop:
  - GnomeRR: Force a refresh of timestamps so other clients won't
    think this is a server-generated event
  - Thumbnail: Look up mimetypes properly
  - GnomeBG: Update for GTK+ 3 changes
  - GnomeBG: Don't try to use a null format
  + Misc:
  - Rename --enable-deprecations configure flag to
  - -enable-deprecation-flags
  + Updated translations.
* Thu Sep  9 2010 vuntz@opensuse.org
- Always make libgnome-desktop-3-0 provide gnome-desktop =
  %%{version} to make lang package installable. However, the
  Obsoletes is only there if %%IS_DEFAULT_GNOME_DESKTOP is set: we
  don't want to obsolete it if it's not the default.
* Wed Sep  8 2010 vuntz@opensuse.org
- Update gnome-desktop to the GNOME 3 version. The GNOME 2 version
  will be kept as the gnome-desktop2 source package.
- There is a IS_DEFAULT_GNOME_DESKTOP default to make it easy to
  choose which gnome-desktop version will be the default. This is
  important since some files like gnome-about and the documentation
  are conflicting between the two versions.
- Update to version 2.90.5. Changes from version 2.31.90:
  + libgnome-desktop:
  - Port to GTK+ 3.0 and make it parallel installable with GTK+
    2.0 version
  - Drop GnomeDesktopItem API
  + Add --disable-desktop-docs configure flag
  + Remove old icons installed in /usr/share/pixmaps
  + Update gnome-about man page
  + Updated translations
- Change old-style BuildRequires to pkgconfig() style
  BuildRequires:
  + old-style: gconf2-devel, gtk2-devel,
    startup-notification-devel.
  + new-style: gconf-2.0, gdk-pixbuf-2.0, glib-2.0, gtk+-3.0,
    libstartup-notification-1.0, x11, xrandr.
- Drop gnome-desktop-fate300461-desktop-gettext.patch,
  gnome-desktop-recently-used-apps.patch, X-KDE-SubstituteUID.dif:
  they were needed for the GnomeDesktopItem API, but it got
  removed.
- Change Requires of lang subpackage to Recommends.
- Remove gnome-core Obsoletes: it's gone for a long time now.
- Create a gnome-about subpackage instead of the main gnome-desktop
  package, since it only contains gnome-about.
- Rename libgnome-desktop-2-17 subpackage to libgnome-desktop-3-0,
  following the library name change upstream.
- Rename devel subpackage to libgnome-desktop-3-devel, and make it
  Provides/Obsoletes gnome-desktop-devel if
  %%IS_DEFAULT_GNOME_DESKTOP is set.
- Make libgnome-desktop-3-0 Provides/Obsoletes gnome-desktop if
  %%IS_DEFAULT_GNOME_DESKTOP is set.
- If %%IS_DEFAULT_GNOME_DESKTOP is not set, pass
  - -disable-gnome-about and --disable-desktop-docs to configure, do
  not look for the help files, and do not create a main package,
  since it would be empty.
- Update description of packages.
* Wed Aug 18 2010 dimstar@opensuse.org
- Update to version 2.31.90:
  + GnomeBG: Be sure to unreference the file_monitor object during
    dispose
  + Add --disable-gnome-about configure flag
  + Updated translations.
* Fri Aug  6 2010 vuntz@opensuse.org
- Update to version 2.31.6:
  + Don't use deprecated Gdk drawing APIs
  + Updated translations.
- Changes from version 2.31.2:
  + GnomeRR: Improve errors from the CRTC assignment process
  + GnomeBG: Fix a case of width-for-height confusion that could
    lead to huge memory consumption on multi-monitor systems
  + Updated translations.
* Tue Mar 30 2010 vuntz@opensuse.org
- Update to version 2.30.0:
  + GnomeRR:
  - Fix build failure with GTK 2.19+
  - Fix build with -DGSEAL_ENABLE
  - Ignore errors when setting the monitor size fails
  + GnomeBG:
  - Fix crash in gradient handling code
  + Misc
  - Really fix build without randr
  + Updated translations.
* Mon Mar  8 2010 dimstar@opensuse.org
- Update to version 2.29.92:
  + libgnome-desktop:
  - GnomeRR: Add new API gnome_rr_output_get_connector_type() and
    gnome_rr_output_is_laptop()
  - GnomeRR: fix leak
  - GnomeRR: build fix
  - GnomeBG: Drop pixbuf cache before switching slides
  + Misc:
  - Make xrandr an optional dependency
  - Add main category to gnome-about desktop file
  + Updated translations.
* Mon Feb 22 2010 vuntz@opensuse.org
- Update to version 2.29.91:
  + GnomeBG:
  - Fix a memory leak
  - Add a picture option to make the background span monitors
  + GnomeDesktopItem:
  - Improve error string
  + Add translator comments
  + Updated translations.
* Wed Feb 10 2010 vuntz@opensuse.org
- Update to version 2.29.90:
  + Updated translations.
* Wed Jan 27 2010 vuntz@opensuse.org
- Update to version 2.29.6:
  + Updated translations.
* Wed Jan 13 2010 captain.magnus@opensuse.org
- Update to version 2.29.5:
  + Bump library soname since ABI was broken in 2.29.4
- Rename libgnome-desktop-2-11 subpackage to libgnome-desktop-2-17,
  following soname change.
- Update the way we remove the ig locale on old versions of
  openSUSE.
- Package baselibs.conf
* Wed Dec 23 2009 vuntz@opensuse.org
- Update to version 2.29.4:
  + GnomeBG:
  - Per-monitor background support
  - Memory leak fixes
  + Updated translations.
* Wed Dec  2 2009 vuntz@opensuse.org
- Update to version 2.29.3:
  + Build improvement
- Changes from version 2.29.2:
  + GnomeRR:
  - Allow rotation if the virtual size has the correct number of
    pixels
  - Add gamma API
  + Updated translations.
* Sat Nov 14 2009 vuntz@opensuse.org
- Update to version 2.28.1:
  + Updated translations.
- Respin gnome-desktop-fate300461-desktop-gettext.patch and
  gnome-desktop-recently-used-apps.patch to apply without fuzz.
* Tue Sep 22 2009 dimstar@opensuse.org
- Update to version 2.28.0:
  + Updated translations.
* Wed Sep  9 2009 vuntz@opensuse.org
- Update to version 2.27.92:
  + Updated translations.
* Wed Aug 26 2009 vuntz@novell.com
- Update to version 2.27.91:
  + GnomeRR:
  - add support for primary monitor
  - in clone mode, don't label each output
  + GnomeBG:
  - add gnome_bg_changes_with_time() API
  - gnome_bg_create_frame_thumbnail() API
  + Build fixes.
  + gnome-about
  - Remove deprecated Encoding key from desktop file
  + Updated translations.
- Respin gnome-desktop-desktop.patch.
- Use spec-cleaner to reorder lines in preamble and split
  BuildRequires/Requires line on separate lines.
* Thu Jul 30 2009 vuntz@novell.com
- Change Requires from gnome-desktop to libgnome-desktop-2-11 in
  devel package.
* Wed Jul 29 2009 vuntz@novell.com
- Update to version 2.27.5:
  + Thumbnail:
  - Fix thumbnailer thread-safety
  + GnomeRR:
  - Get monitor vendor name from pnp.ids
  + gnome-about:
  - Remove libgnome usage
  + Updated translations.
- Do not package omf files twice.
- Ship COPYING.LIB in libgnome-desktop-2-11.
- Remove Requires on libgnome-desktop-2-11 in the main package:
  it's not true.
- Remove Requires on the main package in libgnome-desktop-2-11:
  it's not true either.
* Mon Jul 20 2009 vuntz@novell.com
- Update to version 2.27.4:
  + GnomeRR:
  - Adapt to RANDR 1.3's name for the EDID property
  + Updated translations.
* Tue Jun 16 2009 vuntz@novell.com
- Update to version 2.27.3:
  + GnomeRR:
  - Only select for RRScreenChangeNotifyMask, not for the more
    detailed RANDR 1.2 events
  - Don't ask for RANDR events if the caller doesn't specify a
    callback
  - Add _with_time() versions to the GnomeRR and GnomeRRConfig
    functions that change the RANDR configuration
  - Add gnome_rr_screen_get_timestamps() to query the XRR
    timestamps
  - Don't force a reprobe of the RANDR outputs on every RANDR
    event
  - First update screen resources, then update the screen size
    range
  - Add debug dialog to show the RANDR timestamps
  + Updated translations.
* Wed May 20 2009 vuntz@novell.com
- Update to version 2.26.2:
  + libgnome-desktop
  - Thumbnail: Preload /gnome/desktop/thumbnails in thumbnail
    factory for performance
  - GnomeRR: Fill out ScreenInfo structs sufficiently without
    reprobing
  - GnomeRR: Fix display name heuristics to result less in
    'Unknown'
  - Thumbnail: Code improvements
  - GnomeRR: Don't append a newline to monitor vendor names
  - GnomeRR: Make GnomeRRLabeler's labels explicitly black
  + Misc build system changes.
  + Updated translations.
* Tue Apr 14 2009 vuntz@novell.com
- Update to version 2.26.1:
  + libgnome-desktop
  - GnomeBG: handle X errors when the root properties point to
    something wrong when getting the root pixmap
  - GnomeRR: use XRRGetScreenResourcesCurrent() from RANDR 1.3
    when possible, when we only need to fetch the current RANDR
    status
  + gnome-about
  - Make parsing of gnome-version.xml more tolerant against
    missing fields
  + Misc
  - Add a --disable-date-in-gnome-version configure option to
    remove the build date from gnome-version.xml
  - Remove unused --with-kde-datadir configure option
- Drop gnome-desktop-no-date-in-version.patch: fixed upstream. Also
  disable autoreconf and remove gnome-common BuildRequires (that
  were added for this patch).
* Fri Mar 27 2009 vuntz@novell.com
- Add gnome-desktop-no-date-in-version.patch to be more
  build-compare-friendly, and use new
  - -disable-date-in-gnome-version configure option.
- Enable autoreconf for the patch, and add gnome-common
  BuildRequires.
- Remove -fno-strict-aliasing from CFLAGS.
* Tue Mar 17 2009 vuntz@novell.com
- Update to version 2.26.0:
  + GnomeRR: grab the X server while tweaking the RANDR
    configuration.
  + Remove scrollkeeper check, since it belongs to gnome-doc-utils
  + Updated translations.
- Remove scrollkeeper BuildRequires again.
* Mon Mar  9 2009 vuntz@novell.com
- Add scrollkeeper BuildRequires to fix build.
* Fri Mar  6 2009 vuntz@novell.com
- Update to version 2.25.92:
  + GnomeBG: Allow apps to ignore a pending change so they can
    avoid updating their background twice
  + GnomeBG: Blow all expensive caches if we're not gonna update
    the background again in one minute
  + GnomeBG: Do slightly less steps in slide transitions to avoid
    using to much resources on things that are not visible
  + GnomeBG: Remove outstanding transitions on finalize
  + GnomeRR: Use g_new0() instead of calloc() for consistency
  + GnomeRR: Fix leak
  + GnomeRR: Code cleanup
  + GnomeRR: Revert the change to use
    XRRGetScreenResourcesCurrent(), it's not needed anymore and it
    broke the "Detect Monitors" button
  + General: Make sure that the translation system is initiliazed
    so that translations can be used
  + Updated translations.
* Tue Feb 17 2009 mboman@suse.de
- Add Obsoletes/Provides for merged -doc package
* Tue Feb 17 2009 mboman@suse.de
- Update to version 2.25.91:
  + Translation updates
- Merge -doc into -devel since it only contained gtk-doc
- Remove gnome-common, gtk-doc and scrollkeeper from BuildRequires
* Mon Feb 16 2009 sbrabec@suse.cz
- Added support for translation-update-upstream (FATE#301344).
* Thu Feb  5 2009 mboman@suse.de
- Update to version 2.25.90:
  + GnomeRR: Create a backup file of the configuration when saving
  + GnomeRR: Add public API to get to
    $(XDG_CONFIG_HOME)/monitors.xml and a backup of that file
  + GnomeRR: Add gnome_rr_config_apply_from_filename()
  + GnomeRR: Deprecate gnome_rr_config_apply_stored()
  + Translation updates
* Sun Feb  1 2009 mboman@suse.de
- Update to version 2.25.5:
  + GnomeBG: use gdk_color_equal() instead of custom function
  + GnomeRR: use XRRGetScreenResourcesCurrent instead of
    XRRGetScreenResources when available (xrandr 1.3) because it's
    cheaper
  + GnomeBG: emit "transitioned" signal instead of "changed" signal for
    new frames in a slideshow background
  + GnomeBG: reorganize code a bit
  + GnomeBG: add fading API to support fading between two backgrounds
  + Translation updates
* Sun Feb  1 2009 vuntz@novell.com
- Update gnome-desktop-fate300461-desktop-gettext.patch: the inline
  translations were ignored if they were not matching the first
  language returned by g_get_language_names(), and gettext was
  used. This was not the intended behavior, and made it impossible
  to customize the name/comment of a launcher, eg.
* Fri Jan 23 2009 vuntz@novell.com
- Remove static libraries.
- Remove part of gnome-desktop-desktop.patch that is already
  handled with %%suse_update_desktop_file
- Sanitize BuildRequires and Requires.
- Minor tweaks.
* Fri Jan 23 2009 vuntz@novell.com
- Really drop gnome-desktop-foreign-for-screen.patch, fixed
  upstream.
* Sat Jan 17 2009 crrodriguez@suse.de
- remove "la" files, baby step to clean up all references
  to libavahi-*.la
* Sat Jan 10 2009 mboman@suse.de
- Remove gnome-desktop-randr-gerror.diff. Fixed upstream
* Fri Jan  9 2009 federico@novell.com
- Added gnome-desktop-randr-gerror.diff.  This adds GError reporting
  to the GnomeRR API, which in turn lets gnome-settings-daemon and
  gnome-control-center provide good error messages when something
  fails in multihead configuration.
- Removed gnome-desktop-randr-cloned-outputs.diff, as it is already
  part of the patch above.
* Tue Jan  6 2009 mboman@suse.de
- Update to version 2.25.4:
  + Translation updates
* Sat Dec 20 2008 mboman@suse.de
- Update to version 2.25.3:
  + libgnome-desktop
  - GnomeRR: plug leaks
  - GnomeRR: add API-breaking error reporting API
  - GnomeBG: fix potential crash with some empty slideshow
  - Build fixes
  + Translation updates
* Sun Dec 14 2008 mboman@suse.de
- Update to version 2.25.2:
  + libgnome-desktop
  - GnomeDesktopThumbnail: reenable check for preview::icon
  - GnomeRR: add Lenovo display name
  - GnomeBG: plug a leak
  - GnomeDesktopThumbnail: fix potential crash when a temporary file
    cannot be created
  + Misc
  - Require glib 2.19.1
  - Update a bit API documentation
  - Require GTK+ 2.14.0
  + Translation updates
- Remove icon-search-path.dif. Not valid due to API/ABI changes
- Remove gnome-desktop-randr-cloned-outputs.diff. Fixed upstream
* Tue Nov 11 2008 rodrigo@novell.com
- Add upstream patch for bgo#555701
* Wed Oct 22 2008 maw@suse.de
- Update to version 2.24.1:
  + Updated translations.
* Sat Oct  4 2008 mboman@suse.de
- Update to version 2.24.0:
  + GnomeRR: don't try and set the screen size if turning off any of the
    CRTC's failed
  + GnomeDesktopItem: compute the length of the string passed to
    gnome_desktop_item_new_from_string if the len is not specified
  + Translation updates
* Mon Sep 15 2008 mboman@novell.com
- Update to version 2.23.92:
  + GnomeRR: fix compilation on Solaris
  + Misc: Fix compilation with old Xorg with no pkg-config files
  + Translation updates
* Fri Sep 12 2008 vuntz@novell.com
- Update gnome-desktop-fate300461-desktop-gettext.patch to make it
  able to load translations from the desktop-translations package.
  This is part of fate#300461 again.
* Wed Sep 10 2008 federico@novell.com
- Added gnome-desktop-randr-cloned-outputs.diff to provide
  infrastructure needed to support switching display output modes on
  laptops with the Fn-F7 (XF86Display) hotkey.  The actual handling of
  the hotkey happens in the gnome-settings-daemon package.
* Wed Sep  3 2008 mboman@novell.com
- Update to version 2.23.91:
  + Fix leak
  + GnomeRR: allow E-EDID blocks
  + Fix compilation with old Xorg with no pkg-config files
  + Translation updates
* Fri Aug 29 2008 maw@suse.de
- Update to version 2.23.90:
  + Add support for randr monitor labling (so drop
    gnome-desktop-randr-monitor-labeling.diff, which previously
    implemented this but now is upstream)
  + Updated translations.
* Fri Aug 15 2008 federico@novell.com
- Added gnome-desktop-randr-monitor-labeling.diff.  This implements an
  API to label physical monitors while their RANDR options are being
  configured.
* Tue Aug  5 2008 rodrigo@suse.de
- Update to version 2.23.6:
  + Fix build with gcc 2.x (Jens Granseuer)
  + GnomeBG: fix handling of empty filenames (Soren Sandmann)
  + GnomeBG: word around non-atomic gconf for emitting changed signals
    only once (Soren Sandmann)
- Remove upstreamed randr1.2 patch
* Mon Jul 28 2008 vuntz@novell.com
- Add gnome-desktop-fate300461-desktop-gettext.patch to support
  translation of desktop entries via gettext. This is part of
  fate#300461
* Mon Jul  7 2008 ro@suse.de
- update baselibs.conf
  (it is called libgnome-desktop-2-7 by now)
* Thu Jul  3 2008 aj@suse.de
- Revert last change, it's needed for gnome-panel.
* Mon Jun 30 2008 aj@suse.de
- Remove gnome-desktop from baselibs.conf.
* Fri Jun 20 2008 maw@suse.de
- Update to version 2.23.4:
  + Require intltool 0.40.0
  + Updated translations.
* Mon Jun 16 2008 maw@suse.de
- Update to version 2.23.3:
  + libgnome-desktop:
  * Do not force the top-left corner of the image to fit in
    the screen, so that zoomed image appears to be zoomed from
    the center of the screen
  * Add gnome_bg_load_from_preferences(), so applications don't
    have to rely on libbackground
  * GnomeBG: Fix some logic errors wrt to caching of slideshows
    that may cause nautilus crashes
  * GnomeBG: Support multi-resolution backgrounds
  * GnomeBG: Falls back to the default image if the user's
    background doesn't exist
  * GnomeBG: Prevent loops caused by setting URI
  * GnomeBG: Fix leak
  * GnomeBG: Get rid of URIs and only use paths
  * GnomeBG: Make sure tiles are at least 24 pixels wide
  * GnomeBG: Some tweaks to the tile scaling heuristic
  * GnomeBG: Small fixes
  * GnomeBG: Add getters for the various properties
  * GnomeBG: Monitor the image file
  + gnome-about:
  * Don't skip the last description from gnome-version.xml (Matt Keenan)
  * Convert the strftime() output to UTF-8 (Takao Fujiwara)
  + Updated translations
- Rename the libgnome-desktop shared library subpackage.
* Thu May 29 2008 federico@novell.com
- Updated gnome-desktop-randr-1.2.diff with the latest fixes from upstream.
* Sun May 11 2008 coolo@suse.de
- fix renames of xxbit packages
* Wed May  7 2008 federico@novell.com
- Updated gnome-desktop-randr-1.2.diff with bugfixes from Fedora and Ubuntu.
* Tue Apr 29 2008 cthiel@suse.de
- obsolete gnome-desktop-<arch> via baselibs.conf
* Fri Apr 25 2008 federico@novell.com
- Added gnome-desktop-randr-1.2.diff to integrate the new
  functionality to configure RandR 1.2.
* Mon Apr 21 2008 vuntz@suse.de
- Rewrite gnome-desktop-recently-used-apps.patch so that it
  applies.
* Thu Apr 10 2008 maw@suse.de
- Update to version 2.22.1:
  + Fix some compiler warnings
  + Handle start time in the future correctly in GnomeBG
  + Updated translations.
* Thu Apr 10 2008 ro@suse.de
- added baselibs.conf file to build xxbit packages
  for multilib support
* Tue Apr  1 2008 vuntz@suse.de
- Remove uz@cyrillic workaround (see bnc#372941)
* Fri Mar 14 2008 maw@suse.de
- Update to version 2.22.0:
  + Updated translations.
* Tue Mar  4 2008 maw@suse.de
- Update to version 2.21.92:
  + libgnome-desktop:
  * Fix crash in GnomeBG
  * Fix GnomeBG gio port
  + gnome-about:
  * Fix translator comment not available in po files
  * Fix TypeError crasher in a print statement
  + Misc:
  * Use gvfs-copy instead of gnomevfs-copy in autogen.sh
  + Updated translations.
* Mon Feb 18 2008 maw@suse.de
- Update to version 2.21.91:
  + libgnome-desktop:
  * Fix invalid read
  * Fix compilation issue caused by some headers
  * Port to gio
  * Fix crash in GnomeBG when file is empty
  + gnome-about:
  * Add back a --version option
  + Require gio, and get rid of gnome-vfs
  + Updated translations.
* Fri Feb  1 2008 maw@suse.de
- Update to version 2.21.90:
  + Add GNOME_DESKTOP_USE_UNSTABLE_API API guard
  + Updated translations
- Build with -fno-strict-aliasing.
* Thu Jan 24 2008 rodrigo@suse.de
- Updated to GNOME 2.21.5 version:
  * gnome-about: Don't keep the window centered
  * gnome-about: Fix problem when the color of the logo is wrong
    when changing theme
  * gnome-about: Cleanups
  * gnome-about: Slow down a bit the animation for the description
    so people can actually read it
  * Add check for X11 libraries
  * Translations update
* Tue Sep 18 2007 sbrabec@suse.cz
- Updated to version 2.20.0:
  * gnome-about: Display the list of Foundation members too
  * Remove gnome-vfs dependency for gnome-about
  * Remove spec file
  * Translations update
* Mon Sep 10 2007 mauro@suse.de
- Update to version 2.19.92:
  + Updated translations.
  + Updated README
* Thu Aug 30 2007 maw@suse.de
- Update to version 2.19.90:
  + Updated translations.
* Tue Aug 14 2007 maw@suse.de
- Rename the uz@cyrillic locale directory to uz@Cyrl to avoid
  unowned directories.
* Tue Aug  7 2007 maw@suse.de
- Use %%fdupes
- Split off a -lang subpackage
- s#%%run_ldconfig#/sbin/ldconfig/ in %%post and %%postun.
* Thu Aug  2 2007 mauro@suse.de
- Update to version 2.19.6
- Dependencies fixes.
* Fri Jul  6 2007 maw@suse.de
- Update to version 2.19.4
- Updated translations
- Some tangoified icons
- Requires newer versions of glib2 and gtk2.
* Fri Jun 22 2007 maw@suse.de
- Require libopenssl-devel in the -devel subpackage
- Let the automagic requirements stuff do all the work.
* Thu Jun  7 2007 sbrabec@suse.cz
- Removed invalid desktop Category "Application" (#254654).
* Fri Apr 27 2007 sbrabec@suse.cz
- Do not call meinproc (#227624).
* Wed Apr 11 2007 maw@suse.de
- Update to version 2.18.1
- Minor fixes
- Updated translations for both the documentation (ar and ca)
  and the software itself (dz, es, eu, gl, ku, and lv).
* Fri Mar 23 2007 maw@suse.de
- Update to version 2.18.0
- Few, minor changes.
* Mon Feb 19 2007 maw@suse.de
- Update to version 2.17.91.
* Wed Feb  7 2007 sbrabec@suse.cz
- Do not build unusable static libraries (#238552).
* Sun Jan  7 2007 sbrabec@suse.cz
- Splitted gnome-desktop-doc from gnome-desktop.
* Thu Dec 14 2006 maw@suse.de
- Move to /usr
- Some specfile cleanup.
* Tue Nov 21 2006 sbrabec@suse.cz
- Do not explicitly require mDNSResponder-lib blocking avahi compat
  package.
* Wed Nov 15 2006 jimmyk@suse.de
- Updated recently-used-apps.patch to be compatible with new recently-used
  format, BNC #221392.
* Thu Oct 12 2006 ro@suse.de
- added gnome-doc-utils-devel to buildreq
* Mon Oct  2 2006 jhargadon@suse.de
- update to version 2.16.1
- updated translations
* Wed Sep 13 2006 jhargadon@suse.de
- update to version 2.16.0
- updated translations
* Tue Sep 12 2006 danw@suse.de
- update X-KDE-SubstituteUID.dif for 2.15 and re-enable it. #202076
* Wed Aug 30 2006 jhargadon@suse.de
- update to version 2.15.92
- Remove gnome-workspace icon
- Doc Translations
* Fri Aug 18 2006 jhargadon@suse.de
- update to version 2.15.91
- Use a useful icon theme in gnome_desktop_item_find_icon() when no
  icon theme is passed as argument so we get results
* Fri Aug 11 2006 jhargadon@suse.de
- updated to version 2.15.90
- Set GNOME_PARAM_APP_DATADIR in test application
- Save some memory in gnome-about
- Make URI canonical before using them
- Remember the added locales in GnomeDitemEdit
- Sort locales list in GnomeDitemEdit
- Use gdk_x11_display_get_user_time() to get the launch time
- Don't crash when launching a desktop file without specifying a
  screen
* Mon May  8 2006 jimmyk@suse.de
- Fix recently-used-apps patch, colliding libegg symbols (BNC #158106).
* Mon Mar 20 2006 danw@suse.de
- Fix the error message mentioned in #156801 (though not the dialog
  box, which turns out to be a separate bug).
* Tue Feb 28 2006 jimmyk@suse.de
- Added .recently-used-apps support (BNC #152405)
* Tue Feb 28 2006 sbrabec@suse.cz
- Use kdelibs3-doc in BuildRequires for meinproc (#153635#c14).
* Mon Feb 27 2006 ro@suse.de
- added kdelibs3-devel-doc to BuildRequires
* Sat Feb  4 2006 aj@suse.de
- Reduce BuildRequires.
* Wed Jan 25 2006 mls@suse.de
- converted neededforbuild to BuildRequires
* Wed Nov 30 2005 gekker@suse.de
- Update to version 2.12.2
* Wed Nov 16 2005 sbrabec@suse.cz
- Fixed X-KDE-SubstituteUID patch for commands with arguments
  (#133942).
* Wed Oct 12 2005 gekker@suse.de
- Update to version 2.12.1
* Mon Sep  5 2005 rodrigo@suse.de
- Update to version 2.12.0
* Mon Aug 22 2005 gekker@suse.de
- Update to version 2.11.92
* Tue Aug  2 2005 gekker@suse.de
- Update to version 2.11.90
* Fri Jul 22 2005 gekker@suse.de
- Update to version 2.11.5
* Fri Jun 17 2005 gekker@suse.de
- Update to version 2.11.3
* Wed Jun  1 2005 sbrabec@suse.cz
- Fixed devel requirements.
* Mon May 23 2005 sbrabec@suse.cz
- Require libgnomesu instead of kdebase.
* Fri May 13 2005 sbrabec@suse.cz
- Call gnomesu for root-only binaries.
* Tue Mar 22 2005 sbrabec@suse.cz
- Typo fix in desktop file (#72816).
* Wed Mar 16 2005 clahey@suse.de
- Add an icon (gnome-about-logo-transparent).
* Thu Mar 10 2005 adrian@suse.de
- kick build check workaround and apply translations to desktop file
- show gnome about dialog only in gnome
* Wed Mar  9 2005 gekker@suse.de
- Update to version 2.10.0 (GNOME 2.10).
* Thu Mar  3 2005 gekker@suse.de
- update to version 2.9.92
* Thu Feb 10 2005 gekker@suse.de
- Update to version 2.9.91
* Tue Feb  8 2005 sbrabec@suse.cz
- Changed Categories for gnome-about (#50440).
* Sat Feb  5 2005 gekker@suse.de
- Update to version 2.9.90.1
* Sat Jan 22 2005 gekker@suse.de
- Fixing the broken build
* Fri Jan 21 2005 gekker@suse.de
- Update to version 2.9.4
* Tue Nov  2 2004 ro@suse.de
- locale rename: no -> nb
* Mon Oct  4 2004 sbrabec@suse.cz
- Updated Czech translation (#46621),
* Wed Sep 29 2004 hhetter@suse.de
- change distributor to SUSE
* Mon Sep 20 2004 shprasad@suse.de
- Fixes bug #65062 (Fix given by svasista@novell.com)
  Fixes a crash when menu item is deleted.
* Wed Aug 25 2004 clahey@suse.de
- Cache gnome-desktop help files.
* Thu Aug 19 2004 rml@novell.com
- Fix bug #62316: Use kdesu not gnomesu
* Tue Aug 17 2004 sbrabec@suse.cz
- Added gnomesu needed by X-KDE-SubstituteUID.dif to requires (#43867).
* Wed Jul 28 2004 clahey@suse.de
- Change distributor from GNOME Project to Novell, Inc.
* Tue May  4 2004 clahey@suse.de
- Updated to version 2.6.0.1.
- Updated X-KDE-SubstituteUID based on changes in base package.
- Added patch to provide .directory files for new GNOME menu layout.
* Wed Mar 31 2004 hhetter@suse.de
- added X-KDE-RootOnly Interpretation (#37660)
* Wed Mar 17 2004 hhetter@suse.de
- fix gnomesu call in X-KDE-SubstituteUID
* Mon Mar 15 2004 sbrabec@suse.cz
- FHS 2.3 fix (mandir, infodir, #35821).
* Wed Mar 10 2004 sbrabec@suse.cz
- Fixed %%doc attributes (#33163).
* Sat Jan 10 2004 adrian@suse.de
- add %%defattr and %%run_ldconfig
* Mon Oct 27 2003 sbrabec@suse.cz
- Updated to version 2.4.1.1.
* Fri Oct 17 2003 ro@suse.de
- fix build on x86_64 running all autotools
* Tue Oct  7 2003 sbrabec@suse.cz
- Updated to version 2.4.0 (GNOME 2.4).
* Mon Sep 22 2003 sbrabec@suse.cz
- Obsolete gnome-core (bug #31480),
* Mon Sep 15 2003 hhetter@suse.de
- expand iconpath for KDE crystalsvg stuff in all sizes
* Fri Sep 12 2003 hhetter@suse.de
- enable X-KDE-SubstituteUID
- fix kdedir setting
* Mon Jul 14 2003 sbrabec@suse.cz
- GNOME prefix change to /opt/gnome.
* Tue Jun 24 2003 sbrabec@suse.cz
- Updated to version 2.2.2.
- Use %%find_lang.
- Fixed filelist.
- Compressed man pages.
- Standard docs moved away from gnome-core2.
* Tue Mar  4 2003 hhetter@suse.de
- provide links for susewm icons in first place, making
  the GNOME susewm menu more consistent
* Mon Feb 10 2003 hhetter@suse.de
- updated to version 2.2.0.1 [GNOME 2.2.0]
* Tue Jan 28 2003 hhetter@suse.de
- updated to version 2.2.0
* Thu Jan 16 2003 sbrabec@suse.cz
- Updated to version 2.1.90.
- Updated %%files and license.
* Thu Jan 16 2003 sbrabec@suse.cz
- Added libjpeg to neededforbuild.
* Fri Nov 29 2002 hhetter@suse.de
- add suse paths to the icon loader
* Thu Nov 28 2002 hhetter@suse.de
- updated to version 2.0.10 [GNOME 2.0.3]
- removed hu-translation because translations have been updated
* Mon Nov 11 2002 ro@suse.de
- changed neededforbuild <xf86 xdevel> to <x-devel-packages>
* Tue Sep 24 2002 sbrabec@suse.cz
- Added alsa-devel to neededforbuild, because esound-devel can require it.
* Thu Sep 19 2002 sbrabec@suse.cz
- Added alsa to neededforbuild, because esound can depend on it.
* Tue Sep 17 2002 hhetter@suse.de
- added corrected hu po-files
* Tue Aug 13 2002 hhetter@suse.de
- fix neededforbuild
* Thu Aug  8 2002 hhetter@suse.de
- updated to version 2.0.6
  * Don't stat all icons on startup
  * Fix #89245, picking an .xpm over a .png
  * Also read icons from our installed prefix
  * Fix GConfClient leaks
* Mon Aug  5 2002 hhetter@suse.de
- updated to version 2.0.5
  * fix bogus file reference
* Tue Jul 30 2002 hhetter@suse.de
- updated to version 2.0.4
  * Truncate .desktop file after opening
  * Remove numeric canonization
  * Add APPEND_PATHS flag
  * Sort out libtool versioning
  * Translation updates
* Tue Jul 23 2002 hhetter@suse.de
- updated to version 2.0.3, req. for Nautilus 2.0.1
* Thu Jun 27 2002 hhetter@suse.de
- updated to version 2.0.2 (gnome 2.0 final)
* Thu Jun 20 2002 hhetter@suse.de
- updated to version 2.0.1
* Mon Jun 10 2002 hhetter@suse.de
- updated to version 2.0.0
  - many translation updates
* Tue Jun  4 2002 hhetter@suse.de
- updated to frozen source version 1.5.22
* Wed May 15 2002 ro@suse.de
- use libdir
* Wed Apr 10 2002 hhetter@suse.de
- initial release for GNOME 2.0 platform
